## Django Find My Device

Go into Django Admin

This platform is for locating and controlling your devices. To get started, install FMD Android on your mobile device and use it to register an account on FMD Server.

Remember me for one week

Data

### ID

Auto-refreshing locations is not yet supported. Press the right arrow to query the next location.

Data

### ID

Auto-refreshing locations is not yet supported. Press the right arrow to query the next location.